==> sirikata-0.0.4-mac.tar.gz: sirikata_mac/include/sirikata/core/network/IOServicePool.hpp <==
/*  Sirikata Network Utilities
 *  IOServicePool.hpp
 *
 *  Copyright (c) 2009, Ewen Cheslack-Postava
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of Sirikata nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef _SIRIKATA_IOSERVICE_POOL_HPP_
#define _SIRIKATA_IOSERVICE_POOL_HPP_

#include "IODefs.hpp"
#include "IOService.hpp"

namespace Sirikata {

class Thread;

namespace Network {

/** IOServicePool creates a pool of IOService threads for handling
 *  IO events.
 */
class SIRIKATA_EXPORT IOServicePool {
  public:
    IOServicePool(uint32 nthreads);
    ~IOServicePool();

    /** Run the thread pool. */
    void run();

    /** Reset stopped state */
    void reset();

    /** Block until all the child threads exit. */
    void join();

    /** Add work to keep the service busy. */
    void startWork();

    /** Remove work so the service can complete and exit. */
    void stopWork();

    /** Get the IOService corresponding to the given thread.  Note that
     *  you rarely need a specific service, so requesting the default
     *  is sufficient.
     *  \param thr the index of the thread to retrieve the IOService for
     */
    IOService* service();

  private:
    IOService* mIO;
    typedef std::vector<Thread*> ThreadList;
    ThreadList mThreads;
    IOWork* mWork;
};

} // namespace Network
} // namespace Sirikata

#endif //_SIRIKATA_IOSERVICE_POOL_HPP_

==> sirikata-0.0.21-pre1-mac.tar.gz: sirikata_mac/include/sirikata/core/network/IOServicePool.hpp <==
/*  Sirikata Network Utilities
 *  IOServicePool.hpp
 *
 *  Copyright (c) 2009, Ewen Cheslack-Postava
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of Sirikata nor the names of its contributors may
 *    be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#ifndef _SIRIKATA_IOSERVICE_POOL_HPP_
#define _SIRIKATA_IOSERVICE_POOL_HPP_

#include "IODefs.hpp"
#include "IOService.hpp"

namespace Sirikata {

class Thread;

namespace Network {

/** IOServicePool creates a pool of IOService threads for handling
 *  IO events.
 */
class SIRIKATA_EXPORT IOServicePool {
  public:
    IOServicePool(const String& name, uint32 nthreads);
    ~IOServicePool();

    /** Run the thread pool. */
    void run();

    /** Reset stopped state */
    void reset();

    /** Block until all the child threads exit. */
    void join();

    /** Add work to keep the service busy. */
    void startWork();

    /** Remove work so the service can complete and exit. */
    void stopWork();

    /** Get the IOService corresponding to the given thread.  Note that
     *  you rarely need a specific service, so requesting the default
     *  is sufficient.
     *  \param thr the index of the thread to retrieve the IOService for
     */
    IOService* service();

  private:
    IOService* mIO;
    typedef std::vector<Thread*> ThreadList;
    ThreadList mThreads;
    IOWork* mWork;
};

} // namespace Network
} // namespace Sirikata

#endif //_SIRIKATA_IOSERVICE_POOL_HPP_
